aboutsummaryrefslogtreecommitdiff
path: root/net/src/transports
diff options
context:
space:
mode:
authorhozan23 <hozan23@proton.me>2023-11-30 23:29:25 +0300
committerhozan23 <hozan23@proton.me>2023-11-30 23:29:25 +0300
commitd8425015363cc0ac4742f938dc3f8e9d0beaa933 (patch)
treea0ddf1c3a653eb98bfd4b84eceb8c2ecb9587cfa /net/src/transports
parent7d6c0e68a19ad5e2e4e05cfc219d446be6ff2286 (diff)
net: rename `Listener` trait to `ConnListener`
Diffstat (limited to 'net/src/transports')
-rw-r--r--net/src/transports/tcp.rs6
-rw-r--r--net/src/transports/tls.rs14
-rw-r--r--net/src/transports/unix.rs6
3 files changed, 13 insertions, 13 deletions
diff --git a/net/src/transports/tcp.rs b/net/src/transports/tcp.rs
index 37ad860..7cd7127 100644
--- a/net/src/transports/tcp.rs
+++ b/net/src/transports/tcp.rs
@@ -9,7 +9,7 @@ use smol::{
use crate::{
connection::Connection,
endpoint::{Addr, Endpoint, Port},
- listener::Listener,
+ listener::ConnListener,
Error, Result,
};
@@ -57,7 +57,7 @@ impl Connection for TcpConn {
}
#[async_trait]
-impl Listener for TcpListener {
+impl ConnListener for TcpListener {
fn local_endpoint(&self) -> Result<Endpoint> {
Ok(Endpoint::new_tcp_addr(&self.local_addr()?))
}
@@ -90,7 +90,7 @@ impl From<TcpStream> for Box<dyn Connection> {
}
}
-impl From<TcpListener> for Box<dyn Listener> {
+impl From<TcpListener> for Box<dyn ConnListener> {
fn from(listener: TcpListener) -> Self {
Box::new(listener)
}
diff --git a/net/src/transports/unix.rs b/net/src/transports/unix.rs
index 0698975..c546333 100644
--- a/net/src/transports/unix.rs
+++ b/net/src/transports/unix.rs
@@ -6,7 +6,7 @@ use smol::{
net::unix::{UnixListener, UnixStream},
};
-use crate::{connection::Connection, endpoint::Endpoint, listener::Listener, Error, Result};
+use crate::{connection::Connection, endpoint::Endpoint, listener::ConnListener, Error, Result};
/// Unix domain socket implementation of the [`Connection`] trait.
pub struct UnixConn {
@@ -52,7 +52,7 @@ impl Connection for UnixConn {
}
#[async_trait]
-impl Listener for UnixListener {
+impl ConnListener for UnixListener {
fn local_endpoint(&self) -> Result<Endpoint> {
Ok(Endpoint::new_unix_addr(&self.local_addr()?))
}
@@ -81,7 +81,7 @@ impl From<UnixStream> for Box<dyn Connection> {
}
}
-impl From<UnixListener> for Box<dyn Listener> {
+impl From<UnixListener> for Box<dyn ConnListener> {
fn from(listener: UnixListener) -> Self {
Box::new(listener)
}
diff --git a/net/src/transports/tls.rs b/net/src/transports/tls.rs
index cbb3d99..bc928b0 100644
--- a/net/src/transports/tls.rs
+++ b/net/src/transports/tls.rs
@@ -11,7 +11,7 @@ use smol::{
use crate::{
connection::Connection,
endpoint::{Addr, Endpoint, Port},
- listener::Listener,
+ listener::ConnListener,
Error, Result,
};
@@ -92,14 +92,14 @@ pub async fn dial(
.await
.map(|c| Box::new(c) as Box<dyn Connection>)
}
/// Tls network listener implementation of the [`Listener`] trait.
pub struct TlsListener {
acceptor: TlsAcceptor,
listener: TcpListener,
}
#[async_trait]
-impl Listener for TlsListener {
+impl ConnListener for TlsListener {
fn local_endpoint(&self) -> Result<Endpoint> {
Ok(Endpoint::new_tls_addr(&self.listener.local_addr()?))
}
@@ -124,11 +124,11 @@ pub async fn listen_tls(
Ok(TlsListener { acceptor, listener })
}
/// Listens on the given TLS endpoint, returns [`Listener`].
pub async fn listen(
endpoint: &Endpoint,
config: rustls::ServerConfig,
-) -> Result<Box<dyn Listener>> {
+) -> Result<Box<dyn ConnListener>> {
match endpoint {
Endpoint::Tcp(..) | Endpoint::Tls(..) => {}
_ => return Err(Error::InvalidEndpoint(endpoint.to_string())),
@@ -136,7 +136,7 @@ pub async fn listen(
listen_tls(endpoint.addr()?, endpoint.port()?, config)
.await
- .map(|l| Box::new(l) as Box<dyn Listener>)
+ .map(|l| Box::new(l) as Box<dyn ConnListener>)
}
impl From<TlsStream<TcpStream>> for Box<dyn Connection> {
@@ -145,7 +145,7 @@ impl From<TlsStream<TcpStream>> for Box<dyn Connection> {
}
}
-impl From<TlsListener> for Box<dyn Listener> {
+impl From<TlsListener> for Box<dyn ConnListener> {
fn from(listener: TlsListener) -> Self {
Box::new(listener)
}
@@ -92,14 +92,14 @@ pub async fn dial(
.map(|c| Box::new(c) as Box<dyn Connection>)
}
-/// Tls network listener implementation of the [`Listener`] trait.
+/// Tls network listener implementation of the `Listener` [`ConnListener`] trait.
pub struct TlsListener {
acceptor: TlsAcceptor,
@@ -124,11 +124,11 @@ pub async fn listen_tls(
Ok(TlsListener { acceptor, listener })
}
-/// Listens on the given TLS endpoint, returns [`Listener`].
+/// Listens on the given TLS endpoint, returns `Listener` [`ConnListener`].
pub async fn listen(
endpoint: &Endpoint,